# eric7.Plugins.VcsPlugins.vcsSubversion.SvnCommitDialog

Module implementing a dialog to enter the commit message.

### Global Attributes

None

### Classes

SvnCommitDialog | Class implementing a dialog to enter the commit message.

### Functions

None

## SvnCommitDialog

Class implementing a dialog to enter the commit message.

### Signals

accepted()
  emitted, if the dialog was accepted
rejected()
  emitted, if the dialog was rejected

### Derived from

QWidget, Ui_SvnCommitDialog

### Class Attributes

None

### Class Methods

None

### Methods

SvnCommitDialog | Constructor
changelistsData | Public method to retrieve the changelists data.
hasChangelists | Public method to check, if the user entered some changelists.
logMessage | Public method to retrieve the log message.
on_buttonBox_accepted | Private slot called by the buttonBox accepted signal.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
on_buttonBox_rejected | Private slot called by the buttonBox rejected signal.
on_recentComboBox_activated | Private slot to select a commit message from recent ones.
showEvent | Protected method called when the dialog is about to be shown.

### Static Methods

None

#### SvnCommitDialog (Constructor)

SvnCommitDialog(vcs, parent=None)

Constructor

vcs
  reference to the vcs object
parent
  parent widget (QWidget)

#### SvnCommitDialog.changelistsData

changelistsData()

Public method to retrieve the changelists data.

Return:
  tuple containing the changelists (list of strings) and a flag indicating to keep changelists (boolean)

#### SvnCommitDialog.hasChangelists

hasChangelists()

Public method to check, if the user entered some changelists.

Return:
  flag indicating availability of changelists (boolean)

#### SvnCommitDialog.logMessage

logMessage()

Public method to retrieve the log message.

Return:
  the log message (string)

#### SvnCommitDialog.on_buttonBox_accepted

on_buttonBox_accepted()

Private slot called by the buttonBox accepted signal.

#### SvnCommitDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button
  button that was clicked (QAbstractButton)

#### SvnCommitDialog.on_buttonBox_rejected

on_buttonBox_rejected()

Private slot called by the buttonBox rejected signal.

#### SvnCommitDialog.on_recentComboBox_activated

on_recentComboBox_activated(index)

Private slot to select a commit message from recent ones.

index (int)
  index of the selected entry

#### SvnCommitDialog.showEvent

showEvent(evt)

Protected method called when the dialog is about to be shown.

evt
  the event (QShowEvent)

Up